#
# spec file for package chafa
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           chafa
Version:        1.4.1
Release:        lp152.1.2
Summary:        Image-to-text converter for terminal
License:        LGPL-3.0-or-later
Group:          Amusements/Toys/Graphics
URL:            https://hpjansson.org/chafa/
Source0:        https://github.com/hpjansson/%{name}/releases/download/%{version}/%{name}-%{version}.tar.xz
BuildRequires:  ImageMagick-devel
BuildRequires:  freetype2-devel
BuildRequires:  gcc
BuildRequires:  glib2-devel
BuildRequires:  gtk-doc
BuildRequires:  libtool
Requires:       libchafa0 = %{version}

%description
Chafa is a command-line utility that converts all kinds of images, including
animated image formats like GIFs, into ANSI/Unicode character output that can
be displayed in a terminal.

%package -n libchafa0
Summary:        Shared library for %{name}
Group:          Development/Libraries/C and C++

%description -n libchafa0
The core of Chafa which converts all kinds of images, including
animated image formats like GIFs, into ANSI/Unicode characters.

%package devel
Summary:        Development files for %{name}
Group:          Development/Libraries/C and C++
Requires:       libchafa0 = %{version}

%description devel
Development files for %{name}.

%package doc
Summary:        Chafa documentation
Group:          Documentation/HTML
Recommends:     %{name}-devel
BuildArch:      noarch

%description doc
Documentation for %{name}.

%prep
%setup -q
autoreconf -ivf

# rpath
sed -i -e 's|hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' \
       -e 's|runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' \
       -e "s|runpath_var='LD_RUN_PATH'|runpath_var=DIE_RPATH_DIE|g" \
    configure

%build
%configure --disable-rpath
%make_build

%install
%make_install
rm -rf %{buildroot}%{_libdir}/libchafa.{a,la}

%post -n libchafa0 -p /sbin/ldconfig
%postun -n libchafa0 -p /sbin/ldconfig

%files
%license COPYING.LESSER
%doc README* NEWS
%{_bindir}/%{name}
%{_mandir}/man1/%{name}.1%{?ext_man}

%files -n libchafa0
%license COPYING.LESSER
%{_libdir}/lib%{name}.so.0
%{_libdir}/lib%{name}.so.0.4.0

%files devel
%license COPYING.LESSER
%{_includedir}/%{name}/
%{_libdir}/pkgconfig/%{name}.pc
%{_libdir}/lib%{name}.so
%dir %{_libdir}/chafa/
%{_libdir}/chafa/include/

%files doc
%doc AUTHORS
%license COPYING.LESSER
%doc %{_datadir}/gtk-doc/html/%{name}

%changelog
* Sun Apr 12 2020 Michael Vetter <mvetter@suse.com>
- Update to 1.4.1:
  * Added configure option --disable-rpath. This allows packagers to
    prevent the hard-coded library search path from being embedded in
    the chafa command-line tool (Mo Zhou, #39).
  * Added defaults for the yaft terminal.
  Bug fixes:
  * #40 - Fails to build on hurd-i386 + other i386 (reported by Mo
    Zhou).
  * [unfiled] - Rare failed assert with mostly transparent sixel image
    (reported by Reddit user spryfigure).
  * [unfiled] - Minor typo in function docstring.
* Thu Apr  2 2020 Michael Vetter <mvetter@suse.com>
- Update to 1.4.0:
  * Added sixel graphics support. Chafa will automatically produce sixels
    if the connected terminal supports it. It can also be forced using the
    new -f or --format flag. This is a new implementation written from the
    ground up to maximize throughput.
  * Added the --glyph-file option, which loads glyph-symbol mappings from
    any file format supported by FreeType (TTF, PCF, etc). This allows for
    custom font support and improved symbol selection.
  * Added the --speed option specifying animation speed. It accepts a
    unitless multiplier, a specific number of frames per second, or max
    for maximum throughput.
  * There are now two ways to assign colors to symbol cells. Formerly,
    this was done based on the average color of the covered area. The new
    default is to use the median color, which produces sharper edges,
    but is slightly more prone to high-frequency noise. The new option
  - -color-extractor selects the method to employ.
  * When displaying multiple files, the default delay between files has
    been changed from three seconds to zero. Animations will still play
    through once. This can be overridden on the chafa command line with -d
    or --duration.
  * Minor tweaks to built-in symbols.
  Performance improvements:
  * Halved pixel storage requirements from 64 bits to 32 bits,
    resulting in significant memory savings.
  * Now builds with -ffast-math, yielding a big speedup for DIN99d.
* Wed Mar  4 2020 Michael Vetter <mvetter@suse.com>
- Update to 1.2.2:
  * Fix #34 Cannot compile example
* Sat Aug 24 2019 Jan Engelhardt <jengelh@inai.de>
- Update descriptions.
- Avoid double-shipping documentation, and make docs noarch.
* Tue Aug 20 2019 mvetter@suse.com
- Update to 1.2.1:
  * Detect kitty and mlterm virtual terminals and apply optimal
    defaults accordingly
  * Make Automake build more strict and fix a few compatibility nits
  * Fix #30 - Failed to build on hurd-i386
  * Fix crash on certain broken GIFs
* Mon Aug  5 2019 mvetter@suse.com
- Update to 1.2.0:
  * Added --dither, --dither-grain and --dither-intensity options.
    These allow for sub-cell dithering in quantized modes (none,
    2, 16, 240 and 256). Especially beneficial when used with
  - p off.
  * Added API for ordered and diffusion-based dithering in quantization.
  * Added API support for multiple 8bpc pixel modes: RGB, BGR, RGBA,
    BGRA, ARGB, ABGR with either premultiplied or unassociated alpha channels.
  * Smooth scaling is now done internally, meaning libchafa
    consumers no longer need to prescale images.
  * Implemented a machine learning tool that can generate custom
    fonts for efficient image reproduction from a provided dataset.
    This is left uninstalled since it's still experimental
  * Throughput improvements:
    + GIF animations now start playing instantly.
    + GIF CPU overhead reduced by 75%%, peak memory use down 95%%-99%% (!).
    + XWD common case CPU overhead down 60-70%%, peak memory down 70%%.
    + Additional halving of CPU overhead in 240- and 256-color modes.
    + Streamlined pixel pipeline for better parallelization.
  * Installation instructions:
    + New: Guix (Guy Fleury Iteriteka).
    + New: openSUSE (@jubalh).
  * Bug fixes:
    + [unfiled] Certain SVGs had transparency replaced with a white background (nemo).
    + [unfiled] -lm dependency belongs in libchafa, not frontend.
* Fri Feb  8 2019 mvetter@suse.com
- Initial package chafa 1.0.1 for openSUSE
